searchNodes=[{"doc":"A implementation of RFC 6902 in pure Elixir. The patch can be a single change or a list of things that shall be changed. Therefore a list or a single JSON patch can be provided. Every patch belongs to a certain operation which influences the usage. According to RFC 6901 escaping of / and ~ is done by using ~1 for / and ~0 for ~ .","ref":"Jsonpatch.html","title":"Jsonpatch","type":"module"},{"doc":"Apply a Jsonpatch or a list of Jsonpatches to a map or struct. The whole patch will not be applied when any path is invalid or any other error occured. When a list is provided, the operations are applied in the order as they appear in the list. Examples iex&gt; patch = [ ...&gt; % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } , ...&gt; % Jsonpatch.Operation.Replace { path : &quot;/hobbies/0&quot; , value : &quot;Elixir!&quot; } , ...&gt; % Jsonpatch.Operation.Replace { path : &quot;/married&quot; , value : true } , ...&gt; % Jsonpatch.Operation.Remove { path : &quot;/hobbies/2&quot; } , ...&gt; % Jsonpatch.Operation.Remove { path : &quot;/hobbies/1&quot; } , ...&gt; % Jsonpatch.Operation.Copy { from : &quot;/name&quot; , path : &quot;/surname&quot; } , ...&gt; % Jsonpatch.Operation.Move { from : &quot;/home&quot; , path : &quot;/work&quot; } , ...&gt; % Jsonpatch.Operation.Test { path : &quot;/name&quot; , value : &quot;Bob&quot; } ...&gt; ] iex&gt; target = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Sport&quot; , &quot;Elixir&quot; , &quot;Football&quot; ] , &quot;home&quot; =&gt; &quot;Berlin&quot; } iex&gt; Jsonpatch . apply_patch ( patch , target ) { :ok , %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; true , &quot;hobbies&quot; =&gt; [ &quot;Elixir!&quot; ] , &quot;age&quot; =&gt; 33 , &quot;surname&quot; =&gt; &quot;Bob&quot; , &quot;work&quot; =&gt; &quot;Berlin&quot; } } iex&gt; # Patch will not be applied if test fails. The target will not be changed. iex&gt; patch = [ ...&gt; % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } , ...&gt; % Jsonpatch.Operation.Test { path : &quot;/name&quot; , value : &quot;Alice&quot; } ...&gt; ] iex&gt; target = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Sport&quot; , &quot;Elixir&quot; , &quot;Football&quot; ] , &quot;home&quot; =&gt; &quot;Berlin&quot; } iex&gt; Jsonpatch . apply_patch ( patch , target ) { :error , :test_failed , &quot;Expected value &#39;Alice&#39; at &#39;/name&#39;&quot; }","ref":"Jsonpatch.html#apply_patch/2","title":"Jsonpatch.apply_patch/2","type":"function"},{"doc":"Apply a Jsonpatch or a list of Jsonpatches to a map or struct. In case of an error it will raise an exception. When a list is provided, the operations are applied in the order as they appear in the list. (See Jsonpatch.apply_patch/2 for more details)","ref":"Jsonpatch.html#apply_patch!/2","title":"Jsonpatch.apply_patch!/2","type":"function"},{"doc":"Creates a patch from the difference of a source map to a destination map or list. Examples iex&gt; source = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Elixir&quot; , &quot;Sport&quot; , &quot;Football&quot; ] } iex&gt; destination = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; true , &quot;hobbies&quot; =&gt; [ &quot;Elixir!&quot; ] , &quot;age&quot; =&gt; 33 } iex&gt; Jsonpatch . diff ( source , destination ) [ % Jsonpatch.Operation.Replace { path : &quot;/married&quot; , value : true } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/2&quot; } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/1&quot; } , % Jsonpatch.Operation.Replace { path : &quot;/hobbies/0&quot; , value : &quot;Elixir!&quot; } , % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } ]","ref":"Jsonpatch.html#diff/2","title":"Jsonpatch.diff/2","type":"function"},{"doc":"Describe an error that occured while patching.","ref":"Jsonpatch.html#t:error/0","title":"Jsonpatch.error/0","type":"type"},{"doc":"A valid Jsonpatch operation by RFC 6902","ref":"Jsonpatch.html#t:t/0","title":"Jsonpatch.t/0","type":"type"},{"doc":"Maps JSON patches between regular Maps and list or a single Jsonpatch.Operation.","ref":"Jsonpatch.Mapper.html","title":"Jsonpatch.Mapper","type":"module"},{"doc":"Creates JSON patch struct/s from a single or list maps which represents JSON patches. Examples iex&gt; add_patch_map = %{ &quot;op&quot; =&gt; &quot;add&quot; , &quot;path&quot; =&gt; &quot;/name&quot; , &quot;value&quot; =&gt; &quot;Alice&quot; } iex&gt; Jsonpatch.Mapper . from_map ( add_patch_map ) % Jsonpatch.Operation.Add { path : &quot;/name&quot; , value : &quot;Alice&quot; } iex&gt; unkown_patch_map = %{ &quot;op&quot; =&gt; &quot;foo&quot; , &quot;path&quot; =&gt; &quot;/name&quot; , &quot;value&quot; =&gt; &quot;Alice&quot; } iex&gt; Jsonpatch.Mapper . from_map ( unkown_patch_map ) { :error , :invalid }","ref":"Jsonpatch.Mapper.html#from_map/1","title":"Jsonpatch.Mapper.from_map/1","type":"function"},{"doc":"Turns JSON patches into regular map/s. Examples iex&gt; add_patch_map = % Jsonpatch.Operation.Add { path : &quot;/name&quot; , value : &quot;Alice&quot; } iex&gt; Jsonpatch.Mapper . to_map ( add_patch_map ) %{ op : &quot;add&quot; , path : &quot;/name&quot; , value : &quot;Alice&quot; } iex&gt; add_patch_map = % Jsonpatch.Operation.Add { path : &quot;/name&quot; , value : &quot;Alice&quot; } iex&gt; remove_patch_map = % Jsonpatch.Operation.Remove { path : &quot;/location&quot; } iex&gt; Jsonpatch.Mapper . to_map ( [ add_patch_map , remove_patch_map ] ) [ %{ op : &quot;add&quot; , path : &quot;/name&quot; , value : &quot;Alice&quot; } , %{ op : &quot;remove&quot; , path : &quot;/location&quot; } ]","ref":"Jsonpatch.Mapper.html#to_map/1","title":"Jsonpatch.Mapper.to_map/1","type":"function"},{"doc":"The Operation module is responsible for applying patches. For examples see in the available implementation from this library for this protocol: Jsonpatch.Operation.Add Jsonpatch.Operation.Copy Jsonpatch.Operation.Move Jsonpatch.Operation.Remove Jsonpatch.Operation.Replace Jsonpatch.Operation.Test","ref":"Jsonpatch.Operation.html","title":"Jsonpatch.Operation","type":"protocol"},{"doc":"Executes the given patch to map/struct.","ref":"Jsonpatch.Operation.html#apply_op/2","title":"Jsonpatch.Operation.apply_op/2","type":"function"},{"doc":"","ref":"Jsonpatch.Operation.html#t:t/0","title":"Jsonpatch.Operation.t/0","type":"type"},{"doc":"The add operation is the operation for adding values to a map or struct. Values can be appended to lists by using - instead of an index. Examples iex&gt; add = % Jsonpatch.Operation.Add { path : &quot;/a/b&quot; , value : 1 } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;c&quot; =&gt; false } } iex&gt; Jsonpatch.Operation . apply_op ( add , target ) %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; 1 , &quot;c&quot; =&gt; false } } iex&gt; add = % Jsonpatch.Operation.Add { path : &quot;/a/-&quot; , value : &quot;z&quot; } iex&gt; target = %{ &quot;a&quot; =&gt; [ &quot;x&quot; , &quot;y&quot; ] } iex&gt; Jsonpatch.Operation . apply_op ( add , target ) %{ &quot;a&quot; =&gt; [ &quot;x&quot; , &quot;y&quot; , &quot;z&quot; ] }","ref":"Jsonpatch.Operation.Add.html","title":"Jsonpatch.Operation.Add","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Add.html#t:t/0","title":"Jsonpatch.Operation.Add.t/0","type":"type"},{"doc":"Represents the handling of JSON patches with a copy operation. Examples iex&gt; copy = % Jsonpatch.Operation.Copy { from : &quot;/a/b&quot; , path : &quot;/a/e&quot; } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; %{ &quot;c&quot; =&gt; &quot;Bob&quot; } } , &quot;d&quot; =&gt; false } iex&gt; Jsonpatch.Operation . apply_op ( copy , target ) %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; %{ &quot;c&quot; =&gt; &quot;Bob&quot; } , &quot;e&quot; =&gt; %{ &quot;c&quot; =&gt; &quot;Bob&quot; } } , &quot;d&quot; =&gt; false }","ref":"Jsonpatch.Operation.Copy.html","title":"Jsonpatch.Operation.Copy","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Copy.html#t:t/0","title":"Jsonpatch.Operation.Copy.t/0","type":"type"},{"doc":"Move operations change the position of values in map or struct. Examples iex&gt; move = % Jsonpatch.Operation.Move { from : &quot;/a/b&quot; , path : &quot;/a/e&quot; } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; %{ &quot;c&quot; =&gt; &quot;Bob&quot; } } , &quot;d&quot; =&gt; false } iex&gt; Jsonpatch.Operation . apply_op ( move , target ) %{ &quot;a&quot; =&gt; %{ &quot;e&quot; =&gt; %{ &quot;c&quot; =&gt; &quot;Bob&quot; } } , &quot;d&quot; =&gt; false }","ref":"Jsonpatch.Operation.Move.html","title":"Jsonpatch.Operation.Move","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Move.html#t:t/0","title":"Jsonpatch.Operation.Move.t/0","type":"type"},{"doc":"A JSON patch remove operation is responsible for removing values. Examples iex&gt; remove = % Jsonpatch.Operation.Remove { path : &quot;/a/b&quot; } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; %{ &quot;c&quot; =&gt; &quot;Bob&quot; } } , &quot;d&quot; =&gt; false } iex&gt; Jsonpatch.Operation . apply_op ( remove , target ) %{ &quot;a&quot; =&gt; %{ } , &quot;d&quot; =&gt; false }","ref":"Jsonpatch.Operation.Remove.html","title":"Jsonpatch.Operation.Remove","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Remove.html#t:t/0","title":"Jsonpatch.Operation.Remove.t/0","type":"type"},{"doc":"The replace module helps replacing values in maps and structs by paths. Examples iex&gt; add = % Jsonpatch.Operation.Replace { path : &quot;/a/b&quot; , value : 1 } iex&gt; target = %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; 2 } } iex&gt; Jsonpatch.Operation . apply_op ( add , target ) %{ &quot;a&quot; =&gt; %{ &quot;b&quot; =&gt; 1 } }","ref":"Jsonpatch.Operation.Replace.html","title":"Jsonpatch.Operation.Replace","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Replace.html#t:t/0","title":"Jsonpatch.Operation.Replace.t/0","type":"type"},{"doc":"A test operation in a JSON patch prevents the patch application or allows it. Examples iex&gt; test = % Jsonpatch.Operation.Test { path : &quot;/x/y&quot; , value : &quot;Bob&quot; } iex&gt; target = %{ &quot;x&quot; =&gt; %{ &quot;y&quot; =&gt; &quot;Bob&quot; } } iex&gt; Jsonpatch.Operation . apply_op ( test , target ) %{ &quot;x&quot; =&gt; %{ &quot;y&quot; =&gt; &quot;Bob&quot; } }","ref":"Jsonpatch.Operation.Test.html","title":"Jsonpatch.Operation.Test","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Test.html#t:t/0","title":"Jsonpatch.Operation.Test.t/0","type":"type"},{"doc":"JsonpatchException will be raised if a patch is applied with &quot;!&quot; and the patching fails.","ref":"JsonpatchException.html","title":"JsonpatchException","type":"exception"},{"doc":"Jsonpatch A implementation of RFC 6902 in pure Elixir. Features: Creating a patch by comparing to maps and structs Apply patches to maps and structs - supports operations: add replace remove copy move test De/Encoding and mapping Escaping of &quot; / &quot; (by &quot; ~1 &quot;) and &quot; ~ &quot; (by &quot; ~0 &quot;) Allow usage of - for appending things to list (Add and Copy operation)","ref":"readme.html","title":"Jsonpatch","type":"extras"},{"doc":"Installation The package can be installed by adding jsonpatch to your list of dependencies in mix.exs : def deps do [ { :jsonpatch , &quot;~&gt; 0.12.1&quot; } ] end The docs can be found at https://hexdocs.pm/jsonpatch . Create a diff iex&gt; source = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Sport&quot; , &quot;Elixir&quot; , &quot;Football&quot; ] } iex&gt; destination = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; true , &quot;hobbies&quot; =&gt; [ &quot;Elixir!&quot; ] , &quot;age&quot; =&gt; 33 } iex&gt; Jsonpatch . diff ( source , destination ) { :ok , [ % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } , % Jsonpatch.Operation.Replace { path : &quot;/hobbies/0&quot; , value : &quot;Elixir!&quot; } , % Jsonpatch.Operation.Replace { path : &quot;/married&quot; , value : true } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/1&quot; } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/2&quot; } ] } Mapping for de- and encoding Map a JSON patch struct to a regular map. iex&gt; add_patch_map = % Jsonpatch.Operation.Add { path : &quot;/name&quot; , value : &quot;Alice&quot; } iex&gt; Jsonpatch.Mapper . to_map ( add_patch_map ) %{ op : &quot;add&quot; , path : &quot;/name&quot; , value : &quot;Alice&quot; } Map a regular map to a JSON patch struct. iex&gt; add_patch_map = %{ &quot;op&quot; =&gt; &quot;add&quot; , &quot;path&quot; =&gt; &quot;/name&quot; , &quot;value&quot; =&gt; &quot;Alice&quot; } iex&gt; Jsonpatch.Mapper . from_map ( add_patch_map ) % Jsonpatch.Operation.Add { path : &quot;/name&quot; , value : &quot;Alice&quot; } Apply patches iex&gt; patch = [ % Jsonpatch.Operation.Add { path : &quot;/age&quot; , value : 33 } , % Jsonpatch.Operation.Replace { path : &quot;/hobbies/0&quot; , value : &quot;Elixir!&quot; } , % Jsonpatch.Operation.Replace { path : &quot;/married&quot; , value : true } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/1&quot; } , % Jsonpatch.Operation.Remove { path : &quot;/hobbies/2&quot; } ] iex&gt; target = %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; false , &quot;hobbies&quot; =&gt; [ &quot;Sport&quot; , &quot;Elixir&quot; , &quot;Football&quot; ] } iex&gt; Jsonpatch . apply_patch ( patch , target ) { :ok , %{ &quot;name&quot; =&gt; &quot;Bob&quot; , &quot;married&quot; =&gt; true , &quot;hobbies&quot; =&gt; [ &quot;Elixir!&quot; ] , &quot;age&quot; =&gt; 33 } } In an exs script With Mix.install small scripts can be written to create JSON patches. Mix . install ( [ :jsonpatch , :poison ] ) source = File . read! ( &quot;foo.json&quot; ) |&gt; Poison.Parser . parse! ( %{ } ) destination = File . read! ( &quot;bar.json&quot; ) |&gt; Poison.Parser . parse! ( %{ } ) patch = source |&gt; Jsonpatch . diff ( destination ) |&gt; Jsonpatch.Mapper . to_map ( ) IO . inspect ( patch , label : :patch )","ref":"readme.html#getting-started","title":"Jsonpatch - Getting started","type":"extras"},{"doc":"Official RFC 6902 Inspiration: python-json-patch","ref":"readme.html#important-sources","title":"Jsonpatch - Important sources","type":"extras"}]